from formsite_util.internal.interfaces import FormsiteParams, FormsiteInterface
from formsite_util.internal.auth import FormsiteCredentials

# try:
#     from internal.interfaces import FormsiteParams, FormsiteInterface, FormsiteCredentials
# except ImportError:
#     from .internal.interfaces import FormsiteParams, FormsiteInterface, FormsiteCredentials